##  Why has SAP LeanIX changed its Meta Model?
The evolution of our Meta Model was a natural task for us to accommodate with trends at the interface of business and IT that has become a reality for most of our customers, and for which our Meta Model v3 did not provide the best answers and guidance. The key drivers are:
  * The shift from Project to Product / Co-Existence of Product and Project
  * Implementation of strategic Digital and Technical Platforms
  * Reflection of references to business architecture artifacts (e.g., Value Streams)
  * Modeling of Microservices
  * Classification of Organizational Usage, types of IT Components or Interfaces


We recommend that existing customers adopt the Meta Model v4 if they start new initiatives, e.g., modeling of Business Products. SAP LeanIX has guidelines for that.
